@@ -163,9 +163,11 @@ bool ConfigHandler::checkSaveandTestCommon(bool isSaveCheck)
                     || output->iccProfilePath() != config->iccProfilePath()
                     || output->isHdrEnabled() != config->isHdrEnabled()
                     || output->isWcgEnabled() != config->isWcgEnabled()
-                    || output->sdrBrightness() != config->sdrBrightness()
-                    || output->sdrGamutWideness() != config->sdrGamutWideness()
-                    || output->colorProfileSource() != config->colorProfileSource()) {
+                    || (isSaveCheck && output->sdrBrightness() != config->sdrBrightness())
+                    || (isSaveCheck && output->sdrGamutWideness() != config->sdrGamutWideness())
+                    || output->colorProfileSource() != config->colorProfileSource()
+                    || (isSaveCheck && output->brightness() != config->brightness())
+                    || (isSaveCheck && output->colorPowerPreference() != config->colorPowerPreference())) {
                         return true;
                     }
             }
